@@ -1,8 +1,10 @@
+mod crypto;
 mod general;
 mod interaction;
 mod io;
 
 pub use super::{Box, Vec};
+pub use crypto::*;
 pub use general::*;
 pub use interaction::*;
 pub use io::*;
